@@ -54,11 +54,12 @@ from pyproject_parser.type_hints import (  # noqa: F401
 		ProjectDict,
 		_PyProjectAsTomlDict
 		)
+from pyproject_parser.utils import _load_toml
 
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2021 Dominic Davis-Foster"
 __license__: str = "MIT License"
-__version__: str = "0.8.0"
+__version__: str = "0.9.1"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = ["PyProject", "PyProjectTomlEncoder", "_PP"]
@@ -173,7 +174,7 @@ class PyProject:
 		filename = PathPlus(filename)
 
 		project_dir = filename.parent
-		config = dom_toml.load(filename)
+		config = _load_toml(filename)
 
 		keys = set(config.keys())
 
